<?php
/**
 * @package WordPress
 * @subpackage Classic_Theme
 */

/**
 * ------------------------------------------------------------------------------
 * 1. Theme Setup & Basic Functions
 * ------------------------------------------------------------------------------
 */

// Enable support for automatic feed links
add_theme_support('automatic-feed-links');

// Register sidebar
if ( function_exists('register_sidebar') ) {
    register_sidebar(array(
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '',
        'after_title' => '',
    ));
}

// Filter to remove image attachment links
add_filter('the_content', 'attachment_image_link_remove_filter');
function attachment_image_link_remove_filter($content) {
    $content = preg_replace(
        array('{<a(.*?)(wp-att|wp-content\/uploads)[^>]*><img}', '{ wp-image-[0-9]*" /></a>}'),
        array('<img', '" />'),
        $content
    );
    return $content;
}

// Remove WordPress version from head
remove_action('wp_head', 'wp_generator');

/**
 * ------------------------------------------------------------------------------
 * 2. Yoast & Schema-Related Filters
 * ------------------------------------------------------------------------------
 */

// Ensure breadcrumbs appear in schema
add_filter('wpseo_schema_graph_pieces', 'add_breadcrumbs_to_schema', 10, 2);
function add_breadcrumbs_to_schema($pieces, $context) {
    // Add breadcrumb graph pieces explicitly if needed.
    return $pieces;
}

// Prevent removal of breadcrumb property in WebPage schema
add_filter('wpseo_schema_webpage', 'add_breadcrumb_property_to_webpage', 10, 1);
function add_breadcrumb_property_to_webpage($data) {
    if (!array_key_exists('breadcrumb', $data)) {
        $data['breadcrumb'] = [
            '@type' => 'BreadcrumbList',
            'itemListElement' => [] // Populate dynamically if needed
        ];
    }
    return $data;
}

// Ensure primary image appears in schema
add_filter('wpseo_json_ld_output', 'ensure_primary_image_in_schema', 10, 2);
function ensure_primary_image_in_schema($data) {
    if (isset($data['@type']) && $data['@type'] === 'ImageObject') {
        // Retain ImageObject in schema
        return $data;
    }
    return $data;
}

// Default fallback image for posts without images
add_filter('wpseo_opengraph_image', 'set_default_opengraph_image');
function set_default_opengraph_image($image) {
    if (empty($image)) {
        // Replace with your desired default image URL
        $image = 'https://www.example.com/default-image.jpg';
    }
    return $image;
}

/**
 * ------------------------------------------------------------------------------
 * 3. Remove All Yoast "SearchAction" Markup (Sitelinks Searchbox)
 * ------------------------------------------------------------------------------
 * This filter checks every item in Yoast's final schema graph:
 *   1) If the piece is literally @type=SearchAction, remove it.
 *   2) If the piece has potentialAction containing a @type=SearchAction, remove it.
 * This "nuclear" approach ensures no Sitelinks Searchbox or "query-input" property
 * can appear anywhere in the final JSON-LD.
 */
add_filter('wpseo_schema_graph', 'remove_searchaction_from_graph', 999 );
function remove_searchaction_from_graph( $graph ) {
    foreach ( $graph as $key => $piece ) {
        // 1) If this piece is itself a SearchAction, remove it
        if (isset($piece['@type']) && $piece['@type'] === 'SearchAction') {
            unset($graph[$key]);
            continue;
        }

        // 2) If the piece has a potentialAction that is a SearchAction
        if (isset($piece['potentialAction'])) {
            // potentialAction might be a single object or an array of actions
            if (is_array($piece['potentialAction'])) {
                // If it's an indexed array of multiple potentialActions
                foreach ($piece['potentialAction'] as $paKey => $action) {
                    if (isset($action['@type']) && $action['@type'] === 'SearchAction') {
                        unset($graph[$key]['potentialAction'][$paKey]);
                    }
                }
                // Cleanup empty array if no actions remain
                if (empty($graph[$key]['potentialAction'])) {
                    unset($graph[$key]['potentialAction']);
                }
            } else {
                // If potentialAction is a single object
                $action = $piece['potentialAction'];
                if (isset($action['@type']) && $action['@type'] === 'SearchAction') {
                    unset($graph[$key]['potentialAction']);
                }
            }
        }
    }
    return $graph;
}

/**
 * ------------------------------------------------------------------------------
 * 4. Misc. Front-End
 * ------------------------------------------------------------------------------
 */

// Prevent domain-based links from opening in a new tab
function enqueue_custom_link_handler() {
    // Enqueue the custom-link-handler.js script
    wp_enqueue_script(
        'custom-link-handler',  // Handle or name of the script
        get_template_directory_uri() . '/js/custom-link-handler.js', // Path to your JS file
        array(), // Dependencies
        null,    // Version
        true     // Load in the footer
    );
}
add_action('wp_enqueue_scripts', 'enqueue_custom_link_handler');

?>
